@@ -1,6 +1,6 @@
-package Pcore::Firebird v0.2.3;
+package Pcore::Firebird v0.3.0;
 
-use Pcore -class;
+use Pcore -dist, -class;
 
 1;
 __END__
